###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file he.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::he;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::he::ISA = qw(DateTime::Locale::root);

my @day_names = (
"יום\ שני",
"יום\ שלישי",
"יום\ רביעי",
"יום\ חמישי",
"יום\ שישי",
"שבת",
"יום\ ראשון",
);

my @day_abbreviations = (
"ב",
"ג",
"ד",
"ה",
"ו",
"ש",
"א",
);

my @month_names = (
"ינואר",
"פברואר",
"מרץ",
"אפריל",
"מאי",
"יוני",
"יולי",
"אוגוסט",
"ספטמבר",
"אוקטובר",
"נובמבר",
"דצמבר",
);

my @month_abbreviations = (
"ינו",
"פבר",
"מרץ",
"אפר",
"מאי",
"יונ",
"יול",
"אוג",
"ספט",
"אוק",
"נוב",
"דצמ",
);

my @eras = (
"לסה\"נ",
"לפסה\"נ",
);

my %date_formats = (
"short" => "\%d\/\%m\/\%y",
"medium" => "\%d\/\%m\/\%\{ce_year\}",
"long" => "\%\{day\}\ \%B\ \%\{ce_year\}",
"full" => "\%A\ \%\{day\}\ \%B\ \%\{ce_year\}",
);

my %time_formats = (
"short" => "\%H\:\%M",
"medium" => "\%H\:\%M\:\%S",
"long" => "\%H\:\%M\:\%S\ \%\{time_zone_long_name\}",
"full" => "\%H\:\%M\:\%S\ \%\{time_zone_long_name\}",
);

my $default_date_format_length = "medium";
my $default_time_format_length = "medium";
my $date_parts_order = "dmy";


sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub eras                           { \@eras                           }
sub date_formats                   { \%date_formats                   }
sub time_formats                   { \%time_formats                   }
sub _default_date_format_length    { $default_date_format_length      }
sub _default_time_format_length    { $default_time_format_length      }
sub date_parts_order               { $date_parts_order                }


1;

