###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file mn.xml.
# The source file version number was x0.3, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::mn;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::mn::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Даваа",
"Мягмар",
"Лхагва",
"Пүрэв",
"Баасан",
"Бямба",
"Ням",
);

my @day_abbreviations = (
"Да",
"Мя",
"Лх",
"Пү",
"Ба",
"Бя",
"Ня",
);

my @month_names = (
"1 дүгээр сар",
"2 дугаар сар",
"3 дугаар сар",
"4 дүгээр сар",
"5 дугаар сар",
"6 дугаар сар",
"7 дугаар сар",
"8 дугаар сар",
"9 дүгээр сар",
"10 дугаар сар",
"11 дүгээр сар",
"12 дугаар сар",
);

my @month_abbreviations = (
"I",
"II",
"III",
"IV",
"V",
"VI",
"VII",
"VШ",
"IX",
"X",
"XI",
"XII",
);



sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }


1;

