###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file mt.xml.
# The source file version number was 1.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::mt;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::mt::ISA = qw(DateTime::Locale::root);

my @day_names = (
"It\-Tnejn",
"It\-Tlieta",
"L\-Erbgħa",
"Il\-Ħamis",
"Il\-Ġimgħa",
"Is\-Sibt",
"Il\-Ħadd",
);

my @day_abbreviations = (
"Tne",
"Tli",
"Erb",
"Ħam",
"Ġim",
"Sib",
"Ħad",
);

my @month_names = (
"Jannar",
"Frar",
"Marzu",
"April",
"Mejju",
"Ġunju",
"Lulju",
"Awissu",
"Settembru",
"Ottubru",
"Novembru",
"Diċembru",
);

my @month_abbreviations = (
"Jan",
"Fra",
"Mar",
"Apr",
"Mej",
"Ġun",
"Lul",
"Awi",
"Set",
"Ott",
"Nov",
"Diċ",
);

my @eras = (
"QK",
"WK",
);

my %date_formats = (
"short" => "\%d\/\%m\/\%y",
"medium" => "\%d\-\%b\-\%\{ce_year\}",
"long" => "\%\{day\}\ ta\'\ \%B\ \%\{ce_year\}",
"full" => "\%A\,\ \%\{day\}\ ta\'\ \%B\,\ \%\{ce_year\}",
);

my %time_formats = (
"short" => "\%\{hour_12\}\:\%M\ \%p",
"medium" => "\%\{hour_12\}\:\%M\:\%S\ \%p",
"long" => "\%\{hour_12\}\:\%M\:\%S\ \%p\ \%\{time_zone_long_name\}",
"full" => "\%\{hour_12\}\:\%M\:\%S\ \%p\ \%\{time_zone_long_name\}",
);

my $date_before_time = "1";
my $default_date_format_length = "medium";
my $default_time_format_length = "medium";
my $date_parts_order = "dmy";


sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub eras                           { \@eras                           }
sub date_formats                   { \%date_formats                   }
sub time_formats                   { \%time_formats                   }
sub date_before_time               { $date_before_time                }
sub _default_date_format_length    { $default_date_format_length      }
sub _default_time_format_length    { $default_time_format_length      }
sub date_parts_order               { $date_parts_order                }


1;

