###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file hy_AM_REVISED.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::hy_AM_REVISED;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::hy_AM;

@DateTime::Locale::hy_AM_REVISED::ISA = qw(DateTime::Locale::hy_AM);

my @month_names = (
"Հունվար",
"Փետրվար",
"Մարտ",
"Ապրիլ",
"Մայիս",
"Հունիս",
"Հուլիս",
"Օգոստոս",
"Սեպտեմբեր",
"Հոկտեմբեր",
"Նոյեմբեր",
"Դեկտեմբեր",
);

my @month_abbreviations = (
"Հնվ",
"Փտվ",
"Մրտ",
"Ապր",
"Մյս",
"Հնս",
"Հլս",
"Օգս",
"Սեպ",
"Հոկ",
"Նոյ",
"Դեկ",
);

my @am_pms = (
"Առ․",
"Կե․",
);

my @eras = (
"Մ․Թ․Ա․",
"Մ․Թ․",
);



sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }
sub eras                           { \@eras                           }


1;

