###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file pt.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::pt;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::pt::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Segunda\-feira",
"Terça\-feira",
"Quarta\-feira",
"Quinta\-feira",
"Sexta\-feira",
"Sábado",
"Domingo",
);

my @day_abbreviations = (
"Seg",
"Ter",
"Qua",
"Qui",
"Sex",
"Sáb",
"Dom",
);

my @month_names = (
"Janeiro",
"Fevereiro",
"Março",
"Abril",
"Maio",
"Junho",
"Julho",
"Agosto",
"Setembro",
"Outubro",
"Novembro",
"Dezembro",
);

my @month_abbreviations = (
"Jan",
"Fev",
"Mar",
"Abr",
"Mai",
"Jun",
"Jul",
"Ago",
"Set",
"Out",
"Nov",
"Dez",
);

my %date_formats = (
"short" => "\%d\-\%m\-\%\{ce_year\}",
"medium" => "\%\{day\}\/\%b\/\%\{ce_year\}",
"long" => "\%\{day\}\ de\ \%B\ de\ \%\{ce_year\}",
"full" => "\%A\,\ \%\{day\}\ de\ \%B\ de\ \%\{ce_year\}",
);

my %time_formats = (
"short" => "\%H\:\%M",
"medium" => "\%H\:\%M\:\%S",
"long" => "\%H\:\%M\:\%S\ \%\{time_zone_long_name\}",
"full" => "\%HH\%Mm\ \%\{time_zone_long_name\}",
);

my $date_before_time = "1";
my $default_date_format_length = "medium";
my $default_time_format_length = "medium";
my $date_parts_order = "dmy";


sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub date_formats                   { \%date_formats                   }
sub time_formats                   { \%time_formats                   }
sub date_before_time               { $date_before_time                }
sub _default_date_format_length    { $default_date_format_length      }
sub _default_time_format_length    { $default_time_format_length      }
sub date_parts_order               { $date_parts_order                }


1;

