###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file pa.xml.
# The source file version number was x2.1, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::pa;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::pa::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ਸੋਮਵਾਰ",
"ਮੰਗਲਵਾਰ",
"ਬੁਧਵਾਰ",
"ਵੀਰਵਾਰ",
"ਸ਼ੁੱਕਰਵਾਰ",
"ਸ਼ਨੀਚਰਵਾਰ",
"ਐਤਵਾਰ",
);

my @day_abbreviations = (
"ਸੋਮ\.",
"ਮੰਗਲ\.",
"ਬੁਧ\.",
"ਵੀਰ\.",
"ਸ਼ੁਕਰ\.",
"ਸ਼ਨੀ\.",
"ਐਤ\.",
);

my @month_names = (
"ਜਨਵਰੀ",
"ਫ਼ਰਵਰੀ",
"ਮਾਰਚ",
"ਅਪ੍ਰੈਲ",
"ਮਈ",
"ਜੂਨ",
"ਜੁਲਾਈ",
"ਅਗਸਤ",
"ਸਤੰਬਰ",
"ਅਕਤੂਬਰ",
"ਨਵੰਬਰ",
"ਦਸੰਬਰ",
);

my @month_abbreviations = (
"ਜਨਵਰੀ",
"ਫ਼ਰਵਰੀ",
"ਮਾਰਚ",
"ਅਪ੍ਰੈਲ",
"ਮਈ",
"ਜੂਨ",
"ਜੁਲਾਈ",
"ਅਗਸਤ",
"ਸਤੰਬਰ",
"ਅਕਤੂਬਰ",
"ਨਵੰਬਰ",
"ਦਸੰਬਰ",
);

my @am_pms = (
"ਸਵੇਰੇ",
"ਸ਼ਾਮ",
);



sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }


1;

