###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file zh_MO.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::zh_MO;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::zh;

@DateTime::Locale::zh_MO::ISA = qw(DateTime::Locale::zh);

my @day_abbreviations = (
"一",
"二",
"三",
"四",
"五",
"六",
"日",
);

my @month_abbreviations = (
"1月",
"2月",
"3月",
"4月",
"5月",
"6月",
"7月",
"8月",
"9月",
"10月",
"11月",
"12月",
);

my %date_formats = (
"short" => "\%y年\%\{month\}月\%\{day\}日",
"medium" => "\%\{ce_year\}年\%\{month\}月\%\{day\}日",
"long" => "\%\{ce_year\}年\%m月\%d日\ \%A",
"full" => "\%\{ce_year\}年\%m月\%d日\ \%A",
);

my %time_formats = (
"short" => "\%p\%\{hour_12\}\:\%M",
"medium" => "\%p\%l\:\%M\:\%S",
"long" => "\%p\%l時\%M分\%S秒",
"full" => "\%p\%l時\%M分\%S秒\ \%\{time_zone_long_name\}",
);

my $date_before_time = "1";
my $default_date_format_length = "medium";
my $default_time_format_length = "medium";
my $date_parts_order = "ymd";


sub day_abbreviations              { \@day_abbreviations              }
sub month_abbreviations            { \@month_abbreviations            }
sub date_formats                   { \%date_formats                   }
sub time_formats                   { \%time_formats                   }
sub date_before_time               { $date_before_time                }
sub _default_date_format_length    { $default_date_format_length      }
sub _default_time_format_length    { $default_time_format_length      }
sub date_parts_order               { $date_parts_order                }


1;

