###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file dv.xml.
# The source file version number was x0.3, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::dv;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::dv::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ހޯމަދުވަސް",
"އަންގާރަދުވަސް",
"ބުދަދުވަސް",
"ބުރާސްފަތިދުވަސް",
"ހުކުރުދުވަސް",
"ހޮނިހިރުދުވަސް",
"އާދީއްތަދުވަސް",
);

my @day_abbreviations = (
"ހޯމަ",
"އަންގާރަ",
"ބުދަ",
"ބުރާސްފަތި",
"ހުކުރު",
"ހޮނިހިރު",
"އާދީއްތަ",
);

my @month_names = (
"ޖެނުއަރީ",
"ފެބުރުއަރީ",
"މާޗް",
"އެޕްރިލް",
"މޭއި",
"ޖޫން",
"ޖޫލާއި",
"އޯގަސްޓް",
"ސެޕްޓެމްބަރު",
"އޮކްޓޯބަރު",
"ނޮވެމްބަރު",
"ޑިސެމްބަރު",
);

my @month_abbreviations = (
"ޖެނުއަރީ",
"ފެބުރުއަރީ",
"މާޗް",
"އެޕްރިލް",
"މޭއި",
"ޖޫން",
"ޖޫލާއި",
"އޯގަސްޓް",
"ސެޕްޓެމްބަރު",
"އޮކްޓޯބަރު",
"ނޮވެމްބަރު",
"ޑިސެމްބަރު",
);

my @am_pms = (
"މކ",
"މފ",
);



sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }


1;

