###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ja.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ja;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::ja::ISA = qw(DateTime::Locale::root);

my @day_names = (
"月曜日",
"火曜日",
"水曜日",
"木曜日",
"金曜日",
"土曜日",
"日曜日",
);

my @day_abbreviations = (
"月",
"火",
"水",
"木",
"金",
"土",
"日",
);

my @month_names = (
"1月",
"2月",
"3月",
"4月",
"5月",
"6月",
"7月",
"8月",
"9月",
"10月",
"11月",
"12月",
);

my @month_abbreviations = (
"1",
"2",
"3",
"4",
"5",
"6",
"7",
"8",
"9",
"10",
"11",
"12",
);

my @am_pms = (
"午前",
"午後",
);

my @eras = (
"紀元前",
"西暦",
);

my %date_formats = (
"short" => "\%y\/\%m\/\%d",
"medium" => "\%\{ce_year\}\/\%m\/\%d",
"long" => "\%\{ce_year\}年\%\{month\}月\%\{day\}日",
"full" => "\%\{ce_year\}年\%\{month\}月\%\{day\}日",
);

my %time_formats = (
"short" => "\%\{hour\}\:\%M",
"medium" => "\%\{hour\}\:\%M\:\%S",
"long" => "\%\{hour\}\:\%M\:\%S\:\%\{time_zone_long_name\}",
"full" => "\%\{hour\}時\%M分\%S秒\%\{time_zone_long_name\}",
);

my $date_before_time = "1";
my $default_date_format_length = "medium";
my $default_time_format_length = "medium";
my $date_parts_order = "ymd";


sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }
sub eras                           { \@eras                           }
sub date_formats                   { \%date_formats                   }
sub time_formats                   { \%time_formats                   }
sub date_before_time               { $date_before_time                }
sub _default_date_format_length    { $default_date_format_length      }
sub _default_time_format_length    { $default_time_format_length      }
sub date_parts_order               { $date_parts_order                }


1;

