###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file syr.xml.
# The source file version number was x0.2, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::syr;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::syr::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ܬܪܝܢ ܒܫܒܐ",
"ܬܠܬܐ ܒܫܒܐ",
"ܐܪܒܥܐ ܒܫܒܐ",
"ܚܡܫܐ ܒܫܒܐ",
"ܥܪܘܒܬܐ",
"ܫܒܬܐ",
"ܚܕ ܒܫܒܐ",
);

my @day_abbreviations = (
"܏ܒ ܏ܒܫ",
"܏ܓ ܏ܒܫ",
"܏ܕ ܏ܒܫ",
"܏ܗ ܏ܒܫ",
"܏ܥܪܘܒ",
"܏ܫܒ",
"܏ܐ ܏ܒܫ",
);

my @month_names = (
"ܟܢܘܢ ܐܚܪܝ",
"ܫܒܛ",
"ܐܕܪ",
"ܢܝܣܢ",
"ܐܝܪ",
"ܚܙܝܪܢ",
"ܬܡܘܙ",
"ܐܒ",
"ܐܝܠܘܠ",
"ܬܫܪܝ ܩܕܝܡ",
"ܬܫܪܝ ܐܚܪܝ",
"ܟܢܘܢ ܩܕܝܡ",
);

my @month_abbreviations = (
"܏ܟܢ ܏ܒ",
"ܫܒܛ",
"ܐܕܪ",
"ܢܝܣܢ",
"ܐܝܪ",
"ܚܙܝܪܢ",
"ܬܡܘܙ",
"ܐܒ",
"ܐܝܠܘܠ",
"܏ܬܫ ܏ܐ",
"܏ܬܫ ܏ܒ",
"܏ܟܢ ܏ܐ",
);

my @am_pms = (
"ܩ\.ܛ",
"ܒ\.ܛ",
);



sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }


1;

