###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file kn.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::kn;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::kn::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ಸೋಮವಾರ",
"ಮಂಗಳವಾರ",
"ಬುಧವಾರ",
"ಗುರುವಾರ",
"ಶುಕ್ರವಾರ",
"ಶನಿವಾರ",
"ರವಿವಾರ",
);

my @day_abbreviations = (
"ಸೋ\.",
"ಮಂ\.",
"ಬು\.",
"ಗು\.",
"ಶು\.",
"ಶನಿ\.",
"ರ\.",
);

my @month_names = (
"ಜನವರೀ",
"ಫೆಬ್ರವರೀ",
"ಮಾರ್ಚ್",
"ಎಪ್ರಿಲ್",
"ಮೆ",
"ಜೂನ್",
"ಜುಲೈ",
"ಆಗಸ್ಟ್",
"ಸಪ್ಟೆಂಬರ್",
"ಅಕ್ಟೋಬರ್",
"ನವೆಂಬರ್",
"ಡಿಸೆಂಬರ್",
);

my @month_abbreviations = (
"ಜನವರೀ",
"ಫೆಬ್ರವರೀ",
"ಮಾರ್ಚ್",
"ಎಪ್ರಿಲ್",
"ಮೆ",
"ಜೂನ್",
"ಜುಲೈ",
"ಆಗಸ್ಟ್",
"ಸಪ್ಟೆಂಬರ್",
"ಅಕ್ಟೋಬರ್",
"ನವೆಂಬರ್",
"ಡಿಸೆಂಬರ್",
);

my @am_pms = (
"ಪೂರ್ವಾಹ್ನ",
"ಅಪರಾಹ್ನ",
);



sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }


1;

