###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.01).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file sq.xml.
# The source file version number was 2.0, generated on
# 2003-06-26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sq;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::sq::ISA = qw(DateTime::Locale::root);

my @day_names = (
"e\ hënë",
"e\ martë",
"e\ mërkurë",
"e\ enjte",
"e\ premte",
"e\ shtunë",
"e\ diel",
);

my @day_abbreviations = (
"Hën",
"Mar",
"Mër",
"Enj",
"Pre",
"Sht",
"Die",
);

my @month_names = (
"janar",
"shkurt",
"mars",
"prill",
"maj",
"qershor",
"korrik",
"gusht",
"shtator",
"tetor",
"nëntor",
"dhjetor",
);

my @month_abbreviations = (
"Jan",
"Shk",
"Mar",
"Pri",
"Maj",
"Qer",
"Kor",
"Gsh",
"Sht",
"Tet",
"Nën",
"Dhj",
);

my @am_pms = (
"PD",
"MD",
);

my @eras = (
"p\.e\.r\.",
"n\.e\.r\.",
);

my %date_formats = (
"short" => "\%y\-\%m\-\%d",
"medium" => "\%\{ce_year\}\-\%m\-\%d",
"long" => "\%d\ \%B\ \%\{ce_year\}",
"full" => "\%A\,\ \%d\ \%B\ \%\{ce_year\}",
);

my %time_formats = (
"short" => "\%\{hour_12\}\.\%M\.\%p",
"medium" => "\%\{hour_12\}\:\%M\:\%S\.\%p",
"long" => "\%\{hour_12\}\.\%M\.\%S\.\%p\ \%\{time_zone_long_name\}",
"full" => "\%\{hour_12\}\.\%M\.\%S\.\%p\ \%\{time_zone_long_name\}",
);

my $date_before_time = "1";
my $default_date_format_length = "medium";
my $default_time_format_length = "medium";
my $date_parts_order = "ymd";


sub day_names                      { \@day_names                      }
sub day_abbreviations              { \@day_abbreviations              }
sub month_names                    { \@month_names                    }
sub month_abbreviations            { \@month_abbreviations            }
sub am_pms                         { \@am_pms                         }
sub eras                           { \@eras                           }
sub date_formats                   { \%date_formats                   }
sub time_formats                   { \%time_formats                   }
sub date_before_time               { $date_before_time                }
sub _default_date_format_length    { $default_date_format_length      }
sub _default_time_format_length    { $default_time_format_length      }
sub date_parts_order               { $date_parts_order                }


1;

